@@ -365,7 +365,6 @@ class MemorizingTransformer(nn.Module):
         self.knn_memories_directory = knn_memories_directory
         self.memorizing_layers = unique(memorizing_layers)
         self.num_memory_layers = len(memorizing_layers)
-        assert self.num_memory_layers > 0
 
         self.knn_use_gpu = knn_use_gpu
         self.clear_memories_on_sos_token_id = clear_memories_on_sos_token_id
@@ -435,13 +434,12 @@ class MemorizingTransformer(nn.Module):
 
         # validate KNN memories to have enough indices for batch size
 
-        if exists(knn_memories):
-            assert all([memory.num_indices == batch_size for memory in knn_memories]), f'you passed in an input with batch size {batch_size} but your memories were not instantiated with that number of KNN indices'
+        assert all([memory.num_indices == batch_size for memory in knn_memories]), f'you passed in an input with batch size {batch_size} but your memories were not instantiated with that number of KNN indices'
 
         # if KNN memories are passed in, and researcher wants memories auto-cleared on <sos> token detection
         # do the appropriate logic
 
-        if exists(knn_memories) and exists(self.clear_memories_on_sos_token_id):
+        if exists(self.clear_memories_on_sos_token_id):
             clear_memory = (x == self.clear_memories_on_sos_token_id).any(dim = -1)
             batch_indices, _ = clear_memory.nonzero(as_tuple = True)
             batch_indices_to_clear = batch_indices.tolist()
